Mesa (staging/21.1): bin/pick: Rename master branch to main

GitLab Mirror gitlab-mirror at kemper.freedesktop.org
Mon May 10 21:49:31 UTC 2021


Module: Mesa
Branch: staging/21.1
Commit: 4400387eb5970a5b393879d4b02ede84f4410eee
URL:    http://cgit.freedesktop.org/mesa/mesa/commit/?id=4400387eb5970a5b393879d4b02ede84f4410eee

Author: Jordan Justen <jordan.l.justen at intel.com>
Date:   Mon Apr 26 12:29:30 2021 -0700

bin/pick: Rename master branch to main

Signed-off-by: Jordan Justen <jordan.l.justen at intel.com>
Reviewed-by: Dylan Baker <dylan at pnwbakers.com>
Reviewed-by: Eric Engestrom <eric at engestrom.ch>
(cherry picked from commit 6e86d1f503d8b017bd6679a4db70fef532595f65)

[Eric: botched up Jordan's commit to not break anything on the release branch]

---

 .pick_status.json | 2 +-
 bin/pick/core.py  | 4 ++--
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/.pick_status.json b/.pick_status.json
index 54b8cb70690..f419414e836 100644
--- a/.pick_status.json
+++ b/.pick_status.json
@@ -49,7 +49,7 @@
         "description": "bin/pick: Rename master branch to main",
         "nominated": false,
         "nomination_type": null,
-        "resolution": 4,
+        "resolution": 1,
         "master_sha": null,
         "because_sha": null
     },
diff --git a/bin/pick/core.py b/bin/pick/core.py
index 9b8926224b8..cc0b00f4d40 100644
--- a/bin/pick/core.py
+++ b/bin/pick/core.py
@@ -196,9 +196,9 @@ class Commit:
 
 
 async def get_new_commits(sha: str) -> typing.List[typing.Tuple[str, str]]:
     # Try to get the authoritative upstream master
     p = await asyncio.create_subprocess_exec(
-        'git', 'for-each-ref', '--format=%(upstream)', 'refs/heads/master',
+        'git', 'for-each-ref', '--format=%(upstream)', 'refs/heads/main',
         stdout=asyncio.subprocess.PIPE,
         stderr=asyncio.subprocess.DEVNULL)
     out, _ = await p.communicate()
@@ -196,9 +196,9 @@ class Commit:
 
 async def get_new_commits(sha: str) -> typing.List[typing.Tuple[str, str]]:
-    # Try to get the authoritative upstream master
+    # Try to get the authoritative upstream main
     p = await asyncio.create_subprocess_exec(



More information about the mesa-commit mailing list